@@ -140,8 +140,8 @@ function F=frame(ftype,varargin);
 %@seealso{frana, frsyn, plotframe}
 %@end deftypefn
 
-% Copyright (C) 2005-2022 Peter L. Soendergaard <peter@sonderport.dk> and others.
-% This file is part of LTFAT version 2.5.0
+% Copyright (C) 2005-2023 Peter L. Soendergaard <peter@sonderport.dk> and others.
+% This file is part of LTFAT version 2.6.0
 %
 % This program is free software: you can redistribute it and/or modify
 % it under the terms of the GNU General Public License as published by
@@ -590,12 +590,20 @@ switch(ftype)
   %%%%%%%%%%%%%%%%%%%%
   %% WRAPPER FRAMES %%
   %%%%%%%%%%%%%%%%%%%%
-  case {'erbletfb','cqtfb'}
+  case {'erbletfb','cqtfb', 'waveletfb', 'audletfb', 'warpedfb', 'gaborfb'}
     switch(ftype)
         case 'erbletfb'
             [g,a,~,L] = erbfilters(varargin{:});
         case 'cqtfb'
             [g,a,~,L] = cqtfilters(varargin{:});
+        case 'waveletfb'
+            [g,a,~,L] = waveletfilters(varargin{:});
+        case 'audletfb'
+            [g,a,~,L] = waveletfilters(varargin{:});
+        case 'warpedfb'
+            [g,a,~,L] = waveletfilters(varargin{:});
+        case 'gaborfb'
+            [g,a,~,L] = waveletfilters(varargin{:});
     end
     % Search for the 'complex' flag
     do_complex = ~isempty(varargin(strcmp('complex',varargin)));
