@@ -507,6 +507,13 @@ LTFAT_NAME(fold_array)(const LTFAT_TYPE *in, ltfat_int Lin,
                        ltfat_int offset,
                        ltfat_int Lfold, LTFAT_TYPE *out);
 
+LTFAT_API int
+LTFAT_NAME(clear_array)(LTFAT_TYPE *in, ltfat_int L);
+
+LTFAT_API int
+LTFAT_NAME(log_array)(const LTFAT_TYPE in[], ltfat_int L, LTFAT_TYPE out[]);
+
+
 LTFAT_API int
 LTFAT_NAME(reflect)(const LTFAT_TYPE* in, ltfat_int L, LTFAT_TYPE* out);
 
