@@ -69,7 +69,7 @@ LTFAT_NAME(dgtrealmp_init_gen)(
         CHECK(LTFATERR_NOTAFRAME, M[pIdx] >= a[pIdx],
               "M[%td]>=a[%td] failed passed (%td,%td)", pIdx, pIdx,  M[pIdx], a[pIdx]);
         CHECK(LTFATERR_BADARG, M[pIdx] % a[pIdx] == 0,
-              "M[%td] must be divisible by a[%td]. Passed (%td,%td)", pIdx, pIdx, M, a);
+              "M[%td] must be divisible by a[%td]. Passed (%td,%td)", pIdx, pIdx, M[pIdx], a[pIdx]);
 
         CHECK(LTFATERR_BADARG, gl[pIdx] <= L,
               "gl[%td]<=L failed. Window is too long. passed (%td, %td)",
@@ -291,6 +291,7 @@ LTFAT_NAME(dgtrealmp_reset)(LTFAT_NAME(dgtrealmp_state)* p, const LTFAT_REAL* f)
     int status = LTFATERR_SUCCESS;
 
     LTFAT_NAME(dgtrealmpiter_state)* istate = NULL;
+    LTFAT_REAL initcmax = 0.0;
 
     CHECKNULL(p); CHECKNULL(f);
     istate = p->iterstate;
@@ -331,7 +332,7 @@ LTFAT_NAME(dgtrealmp_reset)(LTFAT_NAME(dgtrealmp_state)* p, const LTFAT_REAL* f)
 
     kpoint origpos;
     LTFAT_NAME(dgtrealmp_execute_findmaxatom)(p, &origpos);
-    LTFAT_REAL initcmax = ltfat_norm(istate->c[PTOI(origpos)]);
+    initcmax = ltfat_norm(istate->c[PTOI(origpos)]);
 
     CHECK( LTFAT_DGTREALMP_STATUS_EMPTY, initcmax > 0.0, " Sanity check (zero max init in prod)");
     p->params->atprodreltoladj = pow(10.0, p->params->atprodreltoldb / 10.0) * initcmax;
@@ -480,7 +481,8 @@ LTFAT_NAME(dgtrealmp_execute_decompose)(
     for (ltfat_int k = 0; k < p->P; k++)
     {
         CHECKNULL(c[k]);
-        memset(c[k], 0, p->M2[k] * p->N[k] * sizeof * c[k]);
+        LTFAT_NAME_COMPLEX(clear_array)( c[k], p->M2[k] * p->N[k]);
+        /* memset(c[k], 0, p->M2[k] * p->N[k] * sizeof * c[k]); */
     }
 
     while ( LTFAT_DGTREALMP_STATUS_CANCONTINUE ==
@@ -650,7 +652,8 @@ LTFAT_NAME(dgtrealmpiter_done)(LTFAT_NAME(dgtrealmpiter_state)** state)
     if (s->tmaxtree)
     {
         for (ltfat_int p = 0; p < s->P; p++)
-            LTFAT_NAME(maxtree_done)(&s->tmaxtree[p]);
+            if (s->tmaxtree[p])
+                LTFAT_NAME(maxtree_done)(&s->tmaxtree[p]);
 
         ltfat_free(s->tmaxtree);
     }
@@ -659,10 +662,14 @@ LTFAT_NAME(dgtrealmpiter_done)(LTFAT_NAME(dgtrealmpiter_state)** state)
     {
         for (ltfat_int p = 0; p < s->P; p++)
         {
-            for (ltfat_int n = 0; n < s->N[p]; n++)
-                LTFAT_NAME(maxtree_done)(&s->fmaxtree[p][n]);
+            if(s->fmaxtree[p])
+            {
+                for (ltfat_int n = 0; n < s->N[p]; n++)
+                    if (s->fmaxtree[p][n])
+                       LTFAT_NAME(maxtree_done)(&s->fmaxtree[p][n]);
 
-            ltfat_free(s->fmaxtree[p]);
+                ltfat_free(s->fmaxtree[p]);
+            }
         }
 
         ltfat_free(s->fmaxtree);
